chemcoord.zmat\_functions.TestOperators
=======================================

.. currentmodule:: chemcoord.zmat_functions

.. autoclass:: TestOperators

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TestOperators.__init__
   
   

   
   
   